cmd

package
v1.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 14, 2026 License: MIT Imports: 40 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var ErrClientManagedKey = errors.New("project uses client-managed encryption")

ErrClientManagedKey indicates that the project uses client-managed encryption

Functions

func Execute

func Execute() error

Execute runs the root command

func HandleAPIError

func HandleAPIError(err error, account *config.Account) error

HandleAPIError provides user-friendly error messages with suggested actions

func NewRootCommand

func NewRootCommand() *cobra.Command

NewRootCommand creates a new root command instance. This is useful for testing as it returns a fresh command tree.

func RefreshOrganizationsIfNeeded

func RefreshOrganizationsIfNeeded(ctx context.Context) error

RefreshOrganizationsIfNeeded checks if organizations need refresh and refreshes them This should be called explicitly when needed, not in a background goroutine

func ShowErrorWithHelp

func ShowErrorWithHelp(err error)

ShowErrorWithHelp displays an error with helpful suggestions

Types

type ReleaseInfo

type ReleaseInfo struct {
	TagName     string `json:"tag_name"`
	Name        string `json:"name"`
	Body        string `json:"body"`
	PublishedAt string `json:"published_at"`
	Assets      []struct {
		Name               string `json:"name"`
		BrowserDownloadURL string `json:"browser_download_url"`
	} `json:"assets"`
}

Jump to