Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrClientManagedKey = errors.New("project uses client-managed encryption")
ErrClientManagedKey indicates that the project uses client-managed encryption
Functions ¶
func HandleAPIError ¶
HandleAPIError provides user-friendly error messages with suggested actions
func NewRootCommand ¶
NewRootCommand creates a new root command instance. This is useful for testing as it returns a fresh command tree.
func RefreshOrganizationsIfNeeded ¶
RefreshOrganizationsIfNeeded checks if organizations need refresh and refreshes them This should be called explicitly when needed, not in a background goroutine
func ShowErrorWithHelp ¶
func ShowErrorWithHelp(err error)
ShowErrorWithHelp displays an error with helpful suggestions
Types ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.